AsrModelDefaults class
Centralized model resource defaults and runtime overrides.
Includes:
- model download URLs
- required model file relative paths
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
downloadUrls
→ const Map<
String, String> - modelsDirName → const String
-
requiredFiles
→ const List<
String> - senseVoiceModelFile → const String
- senseVoiceTokensFile → const String