AsrModelResourceConfig class

Constructors

AsrModelResourceConfig({String modelsDirName = AsrModelDefaults.modelsDirName, List<String> requiredFiles = AsrModelDefaults.requiredFiles, Map<String, String> downloadUrls = AsrModelDefaults.downloadUrls})
const

Properties

downloadUrls Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
modelsDirName String
final
requiredFiles List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited